@@ -202,6 +202,10 @@ MODEL_CLASSES = {
     "MedicationProduct": (None, ".medication"),
     "MedicationProductBatch": (None, ".medication"),
     "MedicationProductIngredient": (None, ".medication"),
+    "MedicationOrder": (None, ".medicationorder"),
+    "MedicationOrderDispenseRequest": (None, ".medicationorder"),
+    "MedicationOrderDosageInstruction": (None, ".medicationorder"),
+    "MedicationOrderSubstitution": (None, ".medicationorder"),
     "Contract": (None, ".contract"),
     "ContractActor": (None, ".contract"),
     "ContractFriendly": (None, ".contract"),
