@@ -16,7 +16,7 @@ from . import element, fhirtypes
 
 
 class Annotation(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -81,6 +81,23 @@ class Annotation(element.Element):
         None, alias="_time", title="Extension field for ``time``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Annotation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "authorReference",
+            "authorReference",
+            "authorReference",
+            "authorString",
+            "time",
+            "text",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1226(
         cls, values: typing.Dict[str, typing.Any]
