@@ -12,7 +12,7 @@ from . import quantity
 
 
 class Count(quantity.Quantity):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -23,3 +23,11 @@ class Count(quantity.Quantity):
     """
 
     resource_type = Field("Count", const=True)
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Count`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "value", "comparator", "unit", "system", "code"]
