@@ -18,7 +18,8 @@ from pydantic.types import (
 )
 from pydantic.validators import bool_validator, parse_date, parse_datetime, parse_time
 
-from .fhirabstractmodel import FHIRAbstractModel
+from fhir.resources.core.fhirabstractmodel import FHIRAbstractModel
+
 from .fhirtypesvalidators import run_validator_for_fhir_type
 
 if TYPE_CHECKING:
@@ -56,7 +57,7 @@ FHIR_PRIMITIVES = [
 class Primitive:
     """FHIR Primitive Data Type Base Class"""
 
-    __fhir_release__: str = "STU3"
+    __fhir_release__: str = "R4"
     __visit_name__: Optional[str] = None
     regex: Optional[Pattern[str]] = None
 
@@ -120,8 +121,8 @@ class String(ConstrainedStr, Primitive):
         However in real use cases, we see empty string is coming other (when the task is related
         to query data from other system)
 
-        It is in your hand now, if you would like to allow empty string!
-        by default empty string is not accepted.
+        It is in your hand now, if you would like to allow empty string! by default
+        empty string is not accepted.
         """
         if isinstance(allow, bool):
             cls.allow_empty_str = allow
@@ -138,6 +139,8 @@ class String(ConstrainedStr, Primitive):
         """ """
         if isinstance(value, bytes):
             value = value.decode()
+        elif value is None:
+            value = ""
         assert isinstance(value, str)
         return value
 
@@ -368,6 +371,7 @@ class Url(AnyUrl, Primitive):
     Common URL protocols are http{s}:, ftp:, mailto: and mllp:,
     though many others are defined"""
 
+    path_regex = re.compile(r"^/(?P<resourceType>[^\s?/]+)(/[^\s?/]+)*")
     __visit_name__ = "url"
 
     @classmethod
@@ -389,8 +393,19 @@ class Url(AnyUrl, Primitive):
         elif value in FHIR_PRIMITIVES:
             # Extensions may contain a valueUrl for a primitive FHIR type
             return value
-
-        return AnyUrl.validate(value, field, config)
+        try:
+            return AnyUrl.validate(value, field, config)
+        except Exception:
+            # we are allowing relative path
+            if not value.startswith("/"):
+                matched = cls.path_regex.match("/" + value)
+            else:
+                matched = cls.path_regex.match(value)
+            if matched is not None:
+                # @ToDo: required resource type validation?
+                # fx: resource type = matched.groupdict().get("resourceType")
+                return value
+            raise
 
     @classmethod
     def to_string(cls, value):
@@ -417,7 +432,7 @@ class Markdown(ConstrainedStr, Primitive):
         return value
 
 
-class Xhtml(ConstrainedStr, Primitive):
+class Xhtml(ConstrainedStr, Primitive):  # type: ignore
     __visit_name__ = "xhtml"
 
     @classmethod
@@ -590,7 +605,7 @@ class Time(datetime.time, Primitive):
     The time "24:00" SHALL NOT be used. A time zone SHALL NOT be present.
     Times can be converted to a Duration since midnight."""
 
-    regex = re.compile(r"([01][0-9]|2[0-3]):[0-5][0-9]:([0-5][0-9]|60)(\.[0-9]+)?")
+    regex = re.compile(r"([01][0-9]|2[0-3]):[0-5][0-9]:[0-5][0-9](\.[0-9]+)?")
     __visit_name__ = "time"
 
     @classmethod
