@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class HealthcareService(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -250,7 +250,7 @@ class HealthcareService(domainresource.DomainResource):
         element_property=True,
     )
 
-    programName: typing.List[fhirtypes.String] = Field(
+    programName: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="programName",
         title="Program Names that categorize the service",
@@ -327,9 +327,50 @@ class HealthcareService(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``HealthcareService`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "active",
+            "providedBy",
+            "category",
+            "type",
+            "specialty",
+            "location",
+            "name",
+            "comment",
+            "extraDetails",
+            "photo",
+            "telecom",
+            "coverageArea",
+            "serviceProvisionCode",
+            "eligibility",
+            "eligibilityNote",
+            "programName",
+            "characteristic",
+            "referralMethod",
+            "appointmentRequired",
+            "availableTime",
+            "notAvailable",
+            "availabilityExceptions",
+            "endpoint",
+        ]
+
 
 class HealthcareServiceAvailableTime(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -406,9 +447,25 @@ class HealthcareServiceAvailableTime(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_daysOfWeek", title="Extension field for ``daysOfWeek``.")
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``HealthcareServiceAvailableTime`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "daysOfWeek",
+            "allDay",
+            "availableStartTime",
+            "availableEndTime",
+        ]
+
 
 class HealthcareServiceNotAvailable(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -447,6 +504,14 @@ class HealthcareServiceNotAvailable(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``HealthcareServiceNotAvailable`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "description", "during"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3105(
         cls, values: typing.Dict[str, typing.Any]
