@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Location(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -37,7 +37,7 @@ class Location(domainresource.DomainResource):
         element_property=True,
     )
 
-    alias: typing.List[fhirtypes.String] = Field(
+    alias: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="alias",
         title=(
@@ -224,9 +224,41 @@ class Location(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Location`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "operationalStatus",
+            "name",
+            "alias",
+            "description",
+            "mode",
+            "type",
+            "telecom",
+            "address",
+            "physicalType",
+            "position",
+            "managingOrganization",
+            "partOf",
+            "endpoint",
+        ]
+
 
 class LocationPosition(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -284,6 +316,21 @@ class LocationPosition(backboneelement.BackboneElement):
         None, alias="_longitude", title="Extension field for ``longitude``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``LocationPosition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "longitude",
+            "latitude",
+            "altitude",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1864(
         cls, values: typing.Dict[str, typing.Any]
