@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class StructureDefinition(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -73,7 +73,7 @@ class StructureDefinition(domainresource.DomainResource):
         element_property=True,
     )
 
-    context: typing.List[fhirtypes.String] = Field(
+    context: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="context",
         title="Where the extension can be used in instances",
@@ -88,7 +88,7 @@ class StructureDefinition(domainresource.DomainResource):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_context", title="Extension field for ``context``.")
 
-    contextInvariant: typing.List[fhirtypes.String] = Field(
+    contextInvariant: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="contextInvariant",
         title="FHIRPath invariants - when the extension can be used",
@@ -462,6 +462,51 @@ class StructureDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``StructureDefinition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "identifier",
+            "version",
+            "name",
+            "title",
+            "status",
+            "experimental",
+            "date",
+            "publisher",
+            "contact",
+            "description",
+            "useContext",
+            "jurisdiction",
+            "purpose",
+            "copyright",
+            "keyword",
+            "fhirVersion",
+            "mapping",
+            "kind",
+            "abstract",
+            "contextType",
+            "context",
+            "contextInvariant",
+            "type",
+            "baseDefinition",
+            "derivation",
+            "snapshot",
+            "differential",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2203(
         cls, values: typing.Dict[str, typing.Any]
@@ -530,7 +575,7 @@ class StructureDefinition(domainresource.DomainResource):
 
 
 class StructureDefinitionDifferential(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -550,9 +595,17 @@ class StructureDefinitionDifferential(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``StructureDefinitionDifferential`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "element"]
+
 
 class StructureDefinitionMapping(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -620,6 +673,22 @@ class StructureDefinitionMapping(backboneelement.BackboneElement):
         None, alias="_uri", title="Extension field for ``uri``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``StructureDefinitionMapping`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "identity",
+            "uri",
+            "name",
+            "comment",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2912(
         cls, values: typing.Dict[str, typing.Any]
@@ -681,7 +750,7 @@ class StructureDefinitionMapping(backboneelement.BackboneElement):
 
 
 class StructureDefinitionSnapshot(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -700,3 +769,11 @@ class StructureDefinitionSnapshot(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``StructureDefinitionSnapshot`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "element"]
