@@ -2,11 +2,12 @@
 from pathlib import Path
 from typing import Any, Dict, Union
 
-from .fhirabstractmodel import FHIRAbstractModel
+from fhir.resources.core.fhirabstractmodel import FHIRAbstractModel
+
 from .fhirtypesvalidators import get_fhir_model_class
 
-__fhir_version__ = "4.0.1"
-__version__ = "6.2.1"
+__fhir_version__ = "4.3.0"
+__version__ = "6.5.0"
 
 
 def construct_fhir_element(
