@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ActivityDefinition
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class ActivityDefinition(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -328,7 +328,7 @@ class ActivityDefinition(domainresource.DomainResource):
         None, alias="_lastReviewDate", title="Extension field for ``lastReviewDate``."
     )
 
-    library: typing.List[fhirtypes.Canonical] = Field(
+    library: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="library",
         title="Logic used by the activity definition",
@@ -459,7 +459,7 @@ class ActivityDefinition(domainresource.DomainResource):
         one_of_many="product",
         one_of_many_required=False,
         # note: Listed Resource Type(s) should be allowed as Reference.
-        enum_reference_types=["Medication", "Substance"],
+        enum_reference_types=["Medication", "Substance", "Ingredient"],
     )
 
     profile: fhirtypes.Canonical = Field(
@@ -578,13 +578,43 @@ class ActivityDefinition(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    subjectCanonical: fhirtypes.Canonical = Field(
+        None,
+        alias="subjectCanonical",
+        title="Type of individual the activity definition is intended for",
+        description=(
+            "A code, group definition, or canonical reference that describes  or "
+            "identifies the intended subject of the activity being defined.  "
+            "Canonical references are allowed to support the definition of "
+            "protocols for drug and substance quality specifications, and is "
+            "allowed to reference a MedicinalProductDefinition, "
+            "SubstanceDefinition, AdministrableProductDefinition, "
+            "ManufacturedItemDefinition, or PackagedProductDefinition resource."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e subject[x]
+        one_of_many="subject",
+        one_of_many_required=False,
+    )
+    subjectCanonical__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_subjectCanonical",
+        title="Extension field for ``subjectCanonical``.",
+    )
+
     subjectCodeableConcept: fhirtypes.CodeableConceptType = Field(
         None,
         alias="subjectCodeableConcept",
         title="Type of individual the activity definition is intended for",
         description=(
-            "A code or group definition that describes the intended subject of the "
-            "activity being defined."
+            "A code, group definition, or canonical reference that describes  or "
+            "identifies the intended subject of the activity being defined.  "
+            "Canonical references are allowed to support the definition of "
+            "protocols for drug and substance quality specifications, and is "
+            "allowed to reference a MedicinalProductDefinition, "
+            "SubstanceDefinition, AdministrableProductDefinition, "
+            "ManufacturedItemDefinition, or PackagedProductDefinition resource."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -598,8 +628,13 @@ class ActivityDefinition(domainresource.DomainResource):
         alias="subjectReference",
         title="Type of individual the activity definition is intended for",
         description=(
-            "A code or group definition that describes the intended subject of the "
-            "activity being defined."
+            "A code, group definition, or canonical reference that describes  or "
+            "identifies the intended subject of the activity being defined.  "
+            "Canonical references are allowed to support the definition of "
+            "protocols for drug and substance quality specifications, and is "
+            "allowed to reference a MedicinalProductDefinition, "
+            "SubstanceDefinition, AdministrableProductDefinition, "
+            "ManufacturedItemDefinition, or PackagedProductDefinition resource."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -838,6 +873,77 @@ class ActivityDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ActivityDefinition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "identifier",
+            "version",
+            "name",
+            "title",
+            "subtitle",
+            "status",
+            "experimental",
+            "subjectCodeableConcept",
+            "subjectReference",
+            "subjectCanonical",
+            "date",
+            "publisher",
+            "contact",
+            "description",
+            "useContext",
+            "jurisdiction",
+            "purpose",
+            "usage",
+            "copyright",
+            "approvalDate",
+            "lastReviewDate",
+            "effectivePeriod",
+            "topic",
+            "author",
+            "editor",
+            "reviewer",
+            "endorser",
+            "relatedArtifact",
+            "library",
+            "kind",
+            "profile",
+            "code",
+            "intent",
+            "priority",
+            "doNotPerform",
+            "timingTiming",
+            "timingDateTime",
+            "timingAge",
+            "timingPeriod",
+            "timingRange",
+            "timingDuration",
+            "location",
+            "participant",
+            "productReference",
+            "productCodeableConcept",
+            "quantity",
+            "dosage",
+            "bodySite",
+            "specimenRequirement",
+            "observationRequirement",
+            "observationResultRequirement",
+            "transform",
+            "dynamicValue",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2053(
         cls, values: typing.Dict[str, typing.Any]
@@ -915,7 +1021,11 @@ class ActivityDefinition(domainresource.DomainResource):
         """
         one_of_many_fields = {
             "product": ["productCodeableConcept", "productReference"],
-            "subject": ["subjectCodeableConcept", "subjectReference"],
+            "subject": [
+                "subjectCanonical",
+                "subjectCodeableConcept",
+                "subjectReference",
+            ],
             "timing": [
                 "timingAge",
                 "timingDateTime",
@@ -948,7 +1058,7 @@ class ActivityDefinition(domainresource.DomainResource):
 
 
 class ActivityDefinitionDynamicValue(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -994,6 +1104,14 @@ class ActivityDefinitionDynamicValue(backboneelement.BackboneElement):
         None, alias="_path", title="Extension field for ``path``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ActivityDefinitionDynamicValue`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "path", "expression"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3262(
         cls, values: typing.Dict[str, typing.Any]
@@ -1055,7 +1173,7 @@ class ActivityDefinitionDynamicValue(backboneelement.BackboneElement):
 
 
 class ActivityDefinitionParticipant(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1093,6 +1211,14 @@ class ActivityDefinitionParticipant(backboneelement.BackboneElement):
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ActivityDefinitionParticipant`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "role"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3210(
         cls, values: typing.Dict[str, typing.Any]
