@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ClaimResponse
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class ClaimResponse(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -362,6 +362,50 @@ class ClaimResponse(domainresource.DomainResource):
         None, alias="_use", title="Extension field for ``use``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponse`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "type",
+            "subType",
+            "use",
+            "patient",
+            "created",
+            "insurer",
+            "requestor",
+            "request",
+            "outcome",
+            "disposition",
+            "preAuthRef",
+            "preAuthPeriod",
+            "payeeType",
+            "item",
+            "addItem",
+            "adjudication",
+            "total",
+            "payment",
+            "fundsReserve",
+            "formCode",
+            "form",
+            "processNote",
+            "communicationRequest",
+            "insurance",
+            "error",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1501(
         cls, values: typing.Dict[str, typing.Any]
@@ -428,7 +472,7 @@ class ClaimResponse(domainresource.DomainResource):
 
 
 class ClaimResponseAddItem(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -466,7 +510,7 @@ class ClaimResponseAddItem(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    detailSequence: typing.List[fhirtypes.PositiveInt] = Field(
+    detailSequence: typing.List[typing.Optional[fhirtypes.PositiveInt]] = Field(
         None,
         alias="detailSequence",
         title="Detail sequence number",
@@ -500,7 +544,7 @@ class ClaimResponseAddItem(backboneelement.BackboneElement):
         None, alias="_factor", title="Extension field for ``factor``."
     )
 
-    itemSequence: typing.List[fhirtypes.PositiveInt] = Field(
+    itemSequence: typing.List[typing.Optional[fhirtypes.PositiveInt]] = Field(
         None,
         alias="itemSequence",
         title="Item sequence number",
@@ -576,7 +620,7 @@ class ClaimResponseAddItem(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    noteNumber: typing.List[fhirtypes.PositiveInt] = Field(
+    noteNumber: typing.List[typing.Optional[fhirtypes.PositiveInt]] = Field(
         None,
         alias="noteNumber",
         title="Applicable note numbers",
@@ -681,7 +725,7 @@ class ClaimResponseAddItem(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    subdetailSequence: typing.List[fhirtypes.PositiveInt] = Field(
+    subdetailSequence: typing.List[typing.Optional[fhirtypes.PositiveInt]] = Field(
         None,
         alias="subdetailSequence",
         title="Subdetail sequence number",
@@ -713,6 +757,39 @@ class ClaimResponseAddItem(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponseAddItem`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "itemSequence",
+            "detailSequence",
+            "subdetailSequence",
+            "provider",
+            "productOrService",
+            "modifier",
+            "programCode",
+            "servicedDate",
+            "servicedPeriod",
+            "locationCodeableConcept",
+            "locationAddress",
+            "locationReference",
+            "quantity",
+            "unitPrice",
+            "factor",
+            "net",
+            "bodySite",
+            "subSite",
+            "noteNumber",
+            "adjudication",
+            "detail",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_2173(
         cls, values: typing.Dict[str, typing.Any]
@@ -760,7 +837,7 @@ class ClaimResponseAddItem(backboneelement.BackboneElement):
 
 
 class ClaimResponseAddItemDetail(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -820,7 +897,7 @@ class ClaimResponseAddItemDetail(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    noteNumber: typing.List[fhirtypes.PositiveInt] = Field(
+    noteNumber: typing.List[typing.Optional[fhirtypes.PositiveInt]] = Field(
         None,
         alias="noteNumber",
         title="Applicable note numbers",
@@ -879,9 +956,30 @@ class ClaimResponseAddItemDetail(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponseAddItemDetail`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "productOrService",
+            "modifier",
+            "quantity",
+            "unitPrice",
+            "factor",
+            "net",
+            "noteNumber",
+            "adjudication",
+            "subDetail",
+        ]
+
 
 class ClaimResponseAddItemDetailSubDetail(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -941,7 +1039,7 @@ class ClaimResponseAddItemDetailSubDetail(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    noteNumber: typing.List[fhirtypes.PositiveInt] = Field(
+    noteNumber: typing.List[typing.Optional[fhirtypes.PositiveInt]] = Field(
         None,
         alias="noteNumber",
         title="Applicable note numbers",
@@ -991,9 +1089,29 @@ class ClaimResponseAddItemDetailSubDetail(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponseAddItemDetailSubDetail`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "productOrService",
+            "modifier",
+            "quantity",
+            "unitPrice",
+            "factor",
+            "net",
+            "noteNumber",
+            "adjudication",
+        ]
+
 
 class ClaimResponseError(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1065,9 +1183,25 @@ class ClaimResponseError(backboneelement.BackboneElement):
         title="Extension field for ``subDetailSequence``.",
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponseError`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "itemSequence",
+            "detailSequence",
+            "subDetailSequence",
+            "code",
+        ]
+
 
 class ClaimResponseInsurance(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1157,6 +1291,23 @@ class ClaimResponseInsurance(backboneelement.BackboneElement):
         None, alias="_sequence", title="Extension field for ``sequence``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponseInsurance`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "sequence",
+            "focal",
+            "coverage",
+            "businessArrangement",
+            "claimResponse",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2437(
         cls, values: typing.Dict[str, typing.Any]
@@ -1218,7 +1369,7 @@ class ClaimResponseInsurance(backboneelement.BackboneElement):
 
 
 class ClaimResponseItem(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1267,7 +1418,7 @@ class ClaimResponseItem(backboneelement.BackboneElement):
         None, alias="_itemSequence", title="Extension field for ``itemSequence``."
     )
 
-    noteNumber: typing.List[fhirtypes.PositiveInt] = Field(
+    noteNumber: typing.List[typing.Optional[fhirtypes.PositiveInt]] = Field(
         None,
         alias="noteNumber",
         title="Applicable note numbers",
@@ -1282,6 +1433,22 @@ class ClaimResponseItem(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_noteNumber", title="Extension field for ``noteNumber``.")
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponseItem`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "itemSequence",
+            "noteNumber",
+            "adjudication",
+            "detail",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1908(
         cls, values: typing.Dict[str, typing.Any]
@@ -1343,7 +1510,7 @@ class ClaimResponseItem(backboneelement.BackboneElement):
 
 
 class ClaimResponseItemAdjudication(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1407,9 +1574,25 @@ class ClaimResponseItemAdjudication(backboneelement.BackboneElement):
         None, alias="_value", title="Extension field for ``value``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponseItemAdjudication`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "category",
+            "reason",
+            "amount",
+            "value",
+        ]
+
 
 class ClaimResponseItemDetail(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1442,7 +1625,7 @@ class ClaimResponseItemDetail(backboneelement.BackboneElement):
         None, alias="_detailSequence", title="Extension field for ``detailSequence``."
     )
 
-    noteNumber: typing.List[fhirtypes.PositiveInt] = Field(
+    noteNumber: typing.List[typing.Optional[fhirtypes.PositiveInt]] = Field(
         None,
         alias="noteNumber",
         title="Applicable note numbers",
@@ -1466,6 +1649,22 @@ class ClaimResponseItemDetail(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponseItemDetail`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "detailSequence",
+            "noteNumber",
+            "adjudication",
+            "subDetail",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2502(
         cls, values: typing.Dict[str, typing.Any]
@@ -1527,7 +1726,7 @@ class ClaimResponseItemDetail(backboneelement.BackboneElement):
 
 
 class ClaimResponseItemDetailSubDetail(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1546,7 +1745,7 @@ class ClaimResponseItemDetailSubDetail(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    noteNumber: typing.List[fhirtypes.PositiveInt] = Field(
+    noteNumber: typing.List[typing.Optional[fhirtypes.PositiveInt]] = Field(
         None,
         alias="noteNumber",
         title="Applicable note numbers",
@@ -1576,6 +1775,21 @@ class ClaimResponseItemDetailSubDetail(backboneelement.BackboneElement):
         title="Extension field for ``subDetailSequence``.",
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponseItemDetailSubDetail`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "subDetailSequence",
+            "noteNumber",
+            "adjudication",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3395(
         cls, values: typing.Dict[str, typing.Any]
@@ -1637,7 +1851,7 @@ class ClaimResponseItemDetailSubDetail(backboneelement.BackboneElement):
 
 
 class ClaimResponsePayment(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1713,9 +1927,27 @@ class ClaimResponsePayment(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponsePayment`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "type",
+            "adjustment",
+            "adjustmentReason",
+            "date",
+            "amount",
+            "identifier",
+        ]
+
 
 class ClaimResponseProcessNote(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1775,6 +2007,22 @@ class ClaimResponseProcessNote(backboneelement.BackboneElement):
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponseProcessNote`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "number",
+            "type",
+            "text",
+            "language",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2642(
         cls, values: typing.Dict[str, typing.Any]
@@ -1836,7 +2084,7 @@ class ClaimResponseProcessNote(backboneelement.BackboneElement):
 
 
 class ClaimResponseTotal(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1870,3 +2118,11 @@ class ClaimResponseTotal(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClaimResponseTotal`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "category", "amount"]
