@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ClinicalImpression
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class ClinicalImpression(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -223,7 +223,7 @@ class ClinicalImpression(domainresource.DomainResource):
         enum_reference_types=["RiskAssessment"],
     )
 
-    protocol: typing.List[fhirtypes.Uri] = Field(
+    protocol: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="protocol",
         title="Clinical Protocol followed",
@@ -298,6 +298,44 @@ class ClinicalImpression(domainresource.DomainResource):
         enum_reference_types=["Resource"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClinicalImpression`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "statusReason",
+            "code",
+            "description",
+            "subject",
+            "encounter",
+            "effectiveDateTime",
+            "effectivePeriod",
+            "date",
+            "assessor",
+            "previous",
+            "problem",
+            "investigation",
+            "protocol",
+            "summary",
+            "finding",
+            "prognosisCodeableConcept",
+            "prognosisReference",
+            "supportingInfo",
+            "note",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2041(
         cls, values: typing.Dict[str, typing.Any]
@@ -397,7 +435,7 @@ class ClinicalImpression(domainresource.DomainResource):
 
 
 class ClinicalImpressionFinding(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -446,9 +484,24 @@ class ClinicalImpressionFinding(backboneelement.BackboneElement):
         enum_reference_types=["Condition", "Observation", "Media"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClinicalImpressionFinding`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "itemCodeableConcept",
+            "itemReference",
+            "basis",
+        ]
+
 
 class ClinicalImpressionInvestigation(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -494,3 +547,11 @@ class ClinicalImpressionInvestigation(backboneelement.BackboneElement):
             "Media",
         ],
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ClinicalImpressionInvestigation`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "code", "item"]
