@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/DataRequirement
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import element, fhirtypes
 
 
 class DataRequirement(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -70,7 +70,7 @@ class DataRequirement(element.Element):
         None, alias="_limit", title="Extension field for ``limit``."
     )
 
-    mustSupport: typing.List[fhirtypes.String] = Field(
+    mustSupport: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="mustSupport",
         title=(
@@ -95,7 +95,7 @@ class DataRequirement(element.Element):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_mustSupport", title="Extension field for ``mustSupport``.")
 
-    profile: typing.List[fhirtypes.Canonical] = Field(
+    profile: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="profile",
         title="The profile of the required data",
@@ -176,6 +176,26 @@ class DataRequirement(element.Element):
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DataRequirement`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "type",
+            "profile",
+            "subjectCodeableConcept",
+            "subjectReference",
+            "mustSupport",
+            "codeFilter",
+            "dateFilter",
+            "limit",
+            "sort",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1731(
         cls, values: typing.Dict[str, typing.Any]
@@ -275,7 +295,7 @@ class DataRequirement(element.Element):
 
 
 class DataRequirementCodeFilter(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -360,9 +380,17 @@ class DataRequirementCodeFilter(element.Element):
         None, alias="_valueSet", title="Extension field for ``valueSet``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DataRequirementCodeFilter`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "path", "searchParam", "valueSet", "code"]
+
 
 class DataRequirementDateFilter(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -475,6 +503,22 @@ class DataRequirementDateFilter(element.Element):
         one_of_many_required=False,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DataRequirementDateFilter`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "path",
+            "searchParam",
+            "valueDateTime",
+            "valuePeriod",
+            "valueDuration",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_2725(
         cls, values: typing.Dict[str, typing.Any]
@@ -517,7 +561,7 @@ class DataRequirementDateFilter(element.Element):
 
 
 class DataRequirementSort(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -562,6 +606,14 @@ class DataRequirementSort(element.Element):
         None, alias="_path", title="Extension field for ``path``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DataRequirementSort`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "path", "direction"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2155(
         cls, values: typing.Dict[str, typing.Any]
