@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Dosage
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -14,7 +14,7 @@ from . import backboneelement, element, fhirtypes
 
 
 class Dosage(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -191,6 +191,32 @@ class Dosage(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Dosage`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "sequence",
+            "text",
+            "additionalInstruction",
+            "patientInstruction",
+            "timing",
+            "asNeededBoolean",
+            "asNeededCodeableConcept",
+            "site",
+            "route",
+            "method",
+            "doseAndRate",
+            "maxDosePerPeriod",
+            "maxDosePerAdministration",
+            "maxDosePerLifetime",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_764(
         cls, values: typing.Dict[str, typing.Any]
@@ -233,7 +259,7 @@ class Dosage(backboneelement.BackboneElement):
 
 
 class DosageDoseAndRate(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -314,6 +340,23 @@ class DosageDoseAndRate(element.Element):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DosageDoseAndRate`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "type",
+            "doseRange",
+            "doseQuantity",
+            "rateRatio",
+            "rateRange",
+            "rateQuantity",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_1830(
         cls, values: typing.Dict[str, typing.Any]
