@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Extension
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -14,7 +14,7 @@ from . import element, fhirtypes
 
 
 class Extension(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -172,6 +172,21 @@ class Extension(element.Element):
         one_of_many_required=False,
     )
 
+    valueCodeableReference: fhirtypes.CodeableReferenceType = Field(
+        None,
+        alias="valueCodeableReference",
+        title="Value of extension",
+        description=(
+            "Value of extension - must be one of a constrained set of the data "
+            "types (see [Extensibility](extensibility.html) for a list)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
     valueCoding: fhirtypes.CodingType = Field(
         None,
         alias="valueCoding",
@@ -457,21 +472,6 @@ class Extension(element.Element):
         one_of_many_required=False,
     )
 
-    valueMeta: fhirtypes.MetaType = Field(
-        None,
-        alias="valueMeta",
-        title="Value of extension",
-        description=(
-            "Value of extension - must be one of a constrained set of the data "
-            "types (see [Extensibility](extensibility.html) for a list)."
-        ),
-        # if property is element of this resource.
-        element_property=True,
-        # Choice of Data Types. i.e value[x]
-        one_of_many="value",
-        one_of_many_required=False,
-    )
-
     valueMoney: fhirtypes.MoneyType = Field(
         None,
         alias="valueMoney",
@@ -592,6 +592,21 @@ class Extension(element.Element):
         one_of_many_required=False,
     )
 
+    valueRatioRange: fhirtypes.RatioRangeType = Field(
+        None,
+        alias="valueRatioRange",
+        title="Value of extension",
+        description=(
+            "Value of extension - must be one of a constrained set of the data "
+            "types (see [Extensibility](extensibility.html) for a list)."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e value[x]
+        one_of_many="value",
+        one_of_many_required=False,
+    )
+
     valueReference: fhirtypes.ReferenceType = Field(
         None,
         alias="valueReference",
@@ -787,6 +802,69 @@ class Extension(element.Element):
         one_of_many_required=False,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Extension`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "url",
+            "valueBase64Binary",
+            "valueBoolean",
+            "valueCanonical",
+            "valueCode",
+            "valueDate",
+            "valueDateTime",
+            "valueDecimal",
+            "valueId",
+            "valueInstant",
+            "valueInteger",
+            "valueMarkdown",
+            "valueOid",
+            "valuePositiveInt",
+            "valueString",
+            "valueTime",
+            "valueUnsignedInt",
+            "valueUri",
+            "valueUrl",
+            "valueUuid",
+            "valueAddress",
+            "valueAge",
+            "valueAnnotation",
+            "valueAttachment",
+            "valueCodeableConcept",
+            "valueCodeableReference",
+            "valueCoding",
+            "valueContactPoint",
+            "valueCount",
+            "valueDistance",
+            "valueDuration",
+            "valueHumanName",
+            "valueIdentifier",
+            "valueMoney",
+            "valuePeriod",
+            "valueQuantity",
+            "valueRange",
+            "valueRatio",
+            "valueRatioRange",
+            "valueReference",
+            "valueSampledData",
+            "valueSignature",
+            "valueTiming",
+            "valueContactDetail",
+            "valueContributor",
+            "valueDataRequirement",
+            "valueExpression",
+            "valueParameterDefinition",
+            "valueRelatedArtifact",
+            "valueTriggerDefinition",
+            "valueUsageContext",
+            "valueDosage",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_1136(
         cls, values: typing.Dict[str, typing.Any]
@@ -814,6 +892,7 @@ class Extension(element.Element):
                 "valueCanonical",
                 "valueCode",
                 "valueCodeableConcept",
+                "valueCodeableReference",
                 "valueCoding",
                 "valueContactDetail",
                 "valueContactPoint",
@@ -833,7 +912,6 @@ class Extension(element.Element):
                 "valueInstant",
                 "valueInteger",
                 "valueMarkdown",
-                "valueMeta",
                 "valueMoney",
                 "valueOid",
                 "valueParameterDefinition",
@@ -842,6 +920,7 @@ class Extension(element.Element):
                 "valueQuantity",
                 "valueRange",
                 "valueRatio",
+                "valueRatioRange",
                 "valueReference",
                 "valueRelatedArtifact",
                 "valueSampledData",
