@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/FamilyMemberHistory
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class FamilyMemberHistory(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -264,7 +264,7 @@ class FamilyMemberHistory(domainresource.DomainResource):
         element_property=True,
     )
 
-    instantiatesCanonical: typing.List[fhirtypes.Canonical] = Field(
+    instantiatesCanonical: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="instantiatesCanonical",
         title="Instantiates FHIR protocol or definition",
@@ -292,7 +292,7 @@ class FamilyMemberHistory(domainresource.DomainResource):
         title="Extension field for ``instantiatesCanonical``.",
     )
 
-    instantiatesUri: typing.List[fhirtypes.Uri] = Field(
+    instantiatesUri: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="instantiatesUri",
         title="Instantiates external protocol or definition",
@@ -422,6 +422,49 @@ class FamilyMemberHistory(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``FamilyMemberHistory`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "instantiatesCanonical",
+            "instantiatesUri",
+            "status",
+            "dataAbsentReason",
+            "patient",
+            "date",
+            "name",
+            "relationship",
+            "sex",
+            "bornPeriod",
+            "bornDate",
+            "bornString",
+            "ageAge",
+            "ageRange",
+            "ageString",
+            "estimatedAge",
+            "deceasedBoolean",
+            "deceasedAge",
+            "deceasedRange",
+            "deceasedDate",
+            "deceasedString",
+            "reasonCode",
+            "reasonReference",
+            "note",
+            "condition",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2155(
         cls, values: typing.Dict[str, typing.Any]
@@ -531,7 +574,7 @@ class FamilyMemberHistory(domainresource.DomainResource):
 
 
 class FamilyMemberHistoryCondition(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -666,6 +709,26 @@ class FamilyMemberHistoryCondition(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``FamilyMemberHistoryCondition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "code",
+            "outcome",
+            "contributedToDeath",
+            "onsetAge",
+            "onsetRange",
+            "onsetPeriod",
+            "onsetString",
+            "note",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_3079(
         cls, values: typing.Dict[str, typing.Any]
