@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/HumanName
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -14,7 +14,7 @@ from . import element, fhirtypes
 
 
 class HumanName(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -39,7 +39,7 @@ class HumanName(element.Element):
         None, alias="_family", title="Extension field for ``family``."
     )
 
-    given: typing.List[fhirtypes.String] = Field(
+    given: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="given",
         title="Given names (not always 'first'). Includes middle names",
@@ -63,7 +63,7 @@ class HumanName(element.Element):
         element_property=True,
     )
 
-    prefix: typing.List[fhirtypes.String] = Field(
+    prefix: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="prefix",
         title="Parts that come before the name",
@@ -79,7 +79,7 @@ class HumanName(element.Element):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_prefix", title="Extension field for ``prefix``.")
 
-    suffix: typing.List[fhirtypes.String] = Field(
+    suffix: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="suffix",
         title="Parts that come after the name",
@@ -133,3 +133,21 @@ class HumanName(element.Element):
     use__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_use", title="Extension field for ``use``."
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``HumanName`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "use",
+            "text",
+            "family",
+            "given",
+            "prefix",
+            "suffix",
+            "period",
+        ]
