@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ImplementationGuide
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -131,7 +131,7 @@ class ImplementationGuide(domainresource.DomainResource):
         None, alias="_experimental", title="Extension field for ``experimental``."
     )
 
-    fhirVersion: typing.List[fhirtypes.Code] = Field(
+    fhirVersion: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="fhirVersion",
         title="FHIR Version(s) this Implementation Guide targets",
@@ -139,7 +139,7 @@ class ImplementationGuide(domainresource.DomainResource):
             "The version(s) of the FHIR specification that this ImplementationGuide"
             " targets - e.g. describes how to use. The value of this element is the"
             " formal version of the specification, without the revision number, "
-            "e.g. [publication].[major].[minor], which is 4.0.1. for this version."
+            "e.g. [publication].[major].[minor], which is 4.3.0 for this version."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1032,7 +1032,7 @@ class ImplementationGuideDefinitionResource(backboneelement.BackboneElement):
         title="Extension field for ``exampleCanonical``.",
     )
 
-    fhirVersion: typing.List[fhirtypes.Code] = Field(
+    fhirVersion: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="fhirVersion",
         title="Versions this applies to (if different to IG)",
@@ -1507,7 +1507,7 @@ class ImplementationGuideManifest(backboneelement.BackboneElement):
 
     resource_type = Field("ImplementationGuideManifest", const=True)
 
-    image: typing.List[fhirtypes.String] = Field(
+    image: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="image",
         title="Image within the IG",
@@ -1519,7 +1519,7 @@ class ImplementationGuideManifest(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_image", title="Extension field for ``image``.")
 
-    other: typing.List[fhirtypes.String] = Field(
+    other: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="other",
         title="Additional linkable file in IG",
@@ -1602,7 +1602,7 @@ class ImplementationGuideManifestPage(backboneelement.BackboneElement):
 
     resource_type = Field("ImplementationGuideManifestPage", const=True)
 
-    anchor: typing.List[fhirtypes.String] = Field(
+    anchor: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="anchor",
         title="Anchor available on the page",
