@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MedicationDispense
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class MedicationDispense(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -389,6 +389,49 @@ class MedicationDispense(domainresource.DomainResource):
         None, alias="_whenPrepared", title="Extension field for ``whenPrepared``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicationDispense`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "partOf",
+            "status",
+            "statusReasonCodeableConcept",
+            "statusReasonReference",
+            "category",
+            "medicationCodeableConcept",
+            "medicationReference",
+            "subject",
+            "context",
+            "supportingInformation",
+            "performer",
+            "location",
+            "authorizingPrescription",
+            "type",
+            "quantity",
+            "daysSupply",
+            "whenPrepared",
+            "whenHandedOver",
+            "destination",
+            "receiver",
+            "note",
+            "dosageInstruction",
+            "substitution",
+            "detectedIssue",
+            "eventHistory",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2026(
         cls, values: typing.Dict[str, typing.Any]
@@ -491,7 +534,7 @@ class MedicationDispense(domainresource.DomainResource):
 
 
 class MedicationDispensePerformer(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -534,9 +577,17 @@ class MedicationDispensePerformer(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicationDispensePerformer`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "function", "actor"]
+
 
 class MedicationDispenseSubstitution(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -607,6 +658,22 @@ class MedicationDispenseSubstitution(backboneelement.BackboneElement):
         None, alias="_wasSubstituted", title="Extension field for ``wasSubstituted``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicationDispenseSubstitution`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "wasSubstituted",
+            "type",
+            "reason",
+            "responsibleParty",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3344(
         cls, values: typing.Dict[str, typing.Any]
