@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MedicationKnowledge
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -283,7 +283,7 @@ class MedicationKnowledge(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
-    synonym: typing.List[fhirtypes.String] = Field(
+    synonym: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="synonym",
         title="Additional names for a medication",
@@ -562,7 +562,7 @@ class MedicationKnowledgeAdministrationGuidelinesPatientCharacteristics(
         one_of_many_required=True,
     )
 
-    value: typing.List[fhirtypes.String] = Field(
+    value: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="value",
         title="The specific characteristic",
@@ -578,8 +578,7 @@ class MedicationKnowledgeAdministrationGuidelinesPatientCharacteristics(
     def elements_sequence(cls):
         """returning all elements names from
         ``MedicationKnowledgeAdministrationGuidelinesPatientCharacteristics``
-        according specification,
-        with preserving original sequence order.
+        according specification, with preserving original sequence order.
         """
         return [
             "id",
