@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MedicationRequest
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class MedicationRequest(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -204,7 +204,7 @@ class MedicationRequest(domainresource.DomainResource):
         element_property=True,
     )
 
-    instantiatesCanonical: typing.List[fhirtypes.Canonical] = Field(
+    instantiatesCanonical: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="instantiatesCanonical",
         title="Instantiates FHIR protocol or definition",
@@ -224,7 +224,7 @@ class MedicationRequest(domainresource.DomainResource):
         title="Extension field for ``instantiatesCanonical``.",
     )
 
-    instantiatesUri: typing.List[fhirtypes.Uri] = Field(
+    instantiatesUri: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="instantiatesUri",
         title="Instantiates external protocol or definition",
@@ -585,6 +585,57 @@ class MedicationRequest(domainresource.DomainResource):
         enum_reference_types=["Resource"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicationRequest`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "statusReason",
+            "intent",
+            "category",
+            "priority",
+            "doNotPerform",
+            "reportedBoolean",
+            "reportedReference",
+            "medicationCodeableConcept",
+            "medicationReference",
+            "subject",
+            "encounter",
+            "supportingInformation",
+            "authoredOn",
+            "requester",
+            "performer",
+            "performerType",
+            "recorder",
+            "reasonCode",
+            "reasonReference",
+            "instantiatesCanonical",
+            "instantiatesUri",
+            "basedOn",
+            "groupIdentifier",
+            "courseOfTherapyType",
+            "insurance",
+            "note",
+            "dosageInstruction",
+            "dispenseRequest",
+            "substitution",
+            "priorPrescription",
+            "detectedIssue",
+            "eventHistory",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1959(
         cls, values: typing.Dict[str, typing.Any]
@@ -687,7 +738,7 @@ class MedicationRequest(domainresource.DomainResource):
 
 
 class MedicationRequestDispenseRequest(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -796,9 +847,28 @@ class MedicationRequestDispenseRequest(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicationRequestDispenseRequest`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "initialFill",
+            "dispenseInterval",
+            "validityPeriod",
+            "numberOfRepeatsAllowed",
+            "quantity",
+            "expectedSupplyDuration",
+            "performer",
+        ]
+
 
 class MedicationRequestDispenseRequestInitialFill(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -827,9 +897,17 @@ class MedicationRequestDispenseRequestInitialFill(backboneelement.BackboneElemen
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicationRequestDispenseRequestInitialFill`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "quantity", "duration"]
+
 
 class MedicationRequestSubstitution(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -887,6 +965,21 @@ class MedicationRequestSubstitution(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicationRequestSubstitution`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "allowedBoolean",
+            "allowedCodeableConcept",
+            "reason",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_3262(
         cls, values: typing.Dict[str, typing.Any]
