@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MessageDefinition
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -192,7 +192,7 @@ class MessageDefinition(domainresource.DomainResource):
         element_property=True,
     )
 
-    graph: typing.List[fhirtypes.Canonical] = Field(
+    graph: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="graph",
         title="Canonical reference to a GraphDefinition",
@@ -253,7 +253,7 @@ class MessageDefinition(domainresource.DomainResource):
         None, alias="_name", title="Extension field for ``name``."
     )
 
-    parent: typing.List[fhirtypes.Canonical] = Field(
+    parent: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="parent",
         title="Protocol/workflow this is part of",
@@ -300,7 +300,7 @@ class MessageDefinition(domainresource.DomainResource):
         None, alias="_purpose", title="Extension field for ``purpose``."
     )
 
-    replaces: typing.List[fhirtypes.Canonical] = Field(
+    replaces: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="replaces",
         title="Takes the place of",
