@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/MolecularSequence
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -666,7 +666,7 @@ class MolecularSequenceQualityRoc(backboneelement.BackboneElement):
 
     resource_type = Field("MolecularSequenceQualityRoc", const=True)
 
-    fMeasure: typing.List[fhirtypes.Decimal] = Field(
+    fMeasure: typing.List[typing.Optional[fhirtypes.Decimal]] = Field(
         None,
         alias="fMeasure",
         title="FScore of the GQ score",
@@ -681,7 +681,7 @@ class MolecularSequenceQualityRoc(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_fMeasure", title="Extension field for ``fMeasure``.")
 
-    numFN: typing.List[fhirtypes.Integer] = Field(
+    numFN: typing.List[typing.Optional[fhirtypes.Integer]] = Field(
         None,
         alias="numFN",
         title="Roc score false negative numbers",
@@ -696,7 +696,7 @@ class MolecularSequenceQualityRoc(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_numFN", title="Extension field for ``numFN``.")
 
-    numFP: typing.List[fhirtypes.Integer] = Field(
+    numFP: typing.List[typing.Optional[fhirtypes.Integer]] = Field(
         None,
         alias="numFP",
         title="Roc score false positive numbers",
@@ -711,7 +711,7 @@ class MolecularSequenceQualityRoc(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_numFP", title="Extension field for ``numFP``.")
 
-    numTP: typing.List[fhirtypes.Integer] = Field(
+    numTP: typing.List[typing.Optional[fhirtypes.Integer]] = Field(
         None,
         alias="numTP",
         title="Roc score true positive numbers",
@@ -726,7 +726,7 @@ class MolecularSequenceQualityRoc(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_numTP", title="Extension field for ``numTP``.")
 
-    precision: typing.List[fhirtypes.Decimal] = Field(
+    precision: typing.List[typing.Optional[fhirtypes.Decimal]] = Field(
         None,
         alias="precision",
         title="Precision of the GQ score",
@@ -741,7 +741,7 @@ class MolecularSequenceQualityRoc(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_precision", title="Extension field for ``precision``.")
 
-    score: typing.List[fhirtypes.Integer] = Field(
+    score: typing.List[typing.Optional[fhirtypes.Integer]] = Field(
         None,
         alias="score",
         title="Genotype quality score",
@@ -756,7 +756,7 @@ class MolecularSequenceQualityRoc(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_score", title="Extension field for ``score``.")
 
-    sensitivity: typing.List[fhirtypes.Decimal] = Field(
+    sensitivity: typing.List[typing.Optional[fhirtypes.Decimal]] = Field(
         None,
         alias="sensitivity",
         title="Sensitivity of the GQ score",
@@ -863,9 +863,10 @@ class MolecularSequenceReferenceSeq(backboneelement.BackboneElement):
         description=(
             "Reference identifier of reference sequence submitted to NCBI. It must "
             "match the type in the MolecularSequence.type field. For example, the "
-            "prefix, \u201cNG_\u201d identifies reference "
-            "sequence for genes, \u201cNM_\u201d for "
-            "messenger RNA transcripts, and \u201cNP_\u201d for amino acid sequences."
+            "prefix, \u201cNG_\u201d identifies "
+            "reference sequence for genes, \u201cNM_\u201d for "
+            "messenger RNA transcripts, and \u201cNP_\u201d "
+            "for amino acid sequences."
         ),
         # if property is element of this resource.
         element_property=True,
