@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/NutritionOrder
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -134,7 +134,7 @@ class NutritionOrder(domainresource.DomainResource):
         element_property=True,
     )
 
-    instantiates: typing.List[fhirtypes.Uri] = Field(
+    instantiates: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="instantiates",
         title="Instantiates protocol or definition",
@@ -152,7 +152,7 @@ class NutritionOrder(domainresource.DomainResource):
         None, alias="_instantiates", title="Extension field for ``instantiates``."
     )
 
-    instantiatesCanonical: typing.List[fhirtypes.Canonical] = Field(
+    instantiatesCanonical: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="instantiatesCanonical",
         title="Instantiates FHIR protocol or definition",
@@ -174,7 +174,7 @@ class NutritionOrder(domainresource.DomainResource):
         title="Extension field for ``instantiatesCanonical``.",
     )
 
-    instantiatesUri: typing.List[fhirtypes.Uri] = Field(
+    instantiatesUri: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="instantiatesUri",
         title="Instantiates external protocol or definition",
