@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/PlanDefinition
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class PlanDefinition(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -24,8 +24,9 @@ class PlanDefinition(domainresource.DomainResource):
     specific patient or context.
     This resource allows for the definition of various types of plans as a
     sharable, consumable, and executable artifact. The resource is general
-    enough to support the description of a broad range of clinical artifacts
-    such as clinical decision support rules, order sets and protocols.
+    enough to support the description of a broad range of clinical and non-
+    clinical artifacts such as clinical decision support rules, order sets,
+    protocols, and drug quality specifications.
     """
 
     resource_type = Field("PlanDefinition", const=True)
@@ -34,7 +35,14 @@ class PlanDefinition(domainresource.DomainResource):
         None,
         alias="action",
         title="Action defined by the plan",
-        description="An action or group of actions to be taken as part of the plan.",
+        description=(
+            "An action or group of actions to be taken as part of the plan. For "
+            "example, in clinical care, an action would be to prescribe a "
+            "particular indicated medication, or perform a particular test as "
+            "appropriate. In pharmaceutical quality, an action would be the test "
+            "that needs to be performed on a drug product as defined in the quality"
+            " specification."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -184,10 +192,11 @@ class PlanDefinition(domainresource.DomainResource):
         alias="goal",
         title="What the plan is trying to accomplish",
         description=(
-            "Goals that describe what the activities within the plan are intended "
-            "to achieve. For example, weight loss, restoring an activity of daily "
-            "living, obtaining herd immunity via immunization, meeting a process "
-            "improvement objective, etc."
+            "A goal describes an expected outcome that activities within the plan "
+            "are intended to achieve. For example, weight loss, restoring an "
+            "activity of daily living, obtaining herd immunity via immunization, "
+            "meeting a process improvement objective, meeting the acceptance "
+            "criteria for a test as specified by a quality specification, etc."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -234,7 +243,7 @@ class PlanDefinition(domainresource.DomainResource):
         None, alias="_lastReviewDate", title="Extension field for ``lastReviewDate``."
     )
 
-    library: typing.List[fhirtypes.Canonical] = Field(
+    library: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="library",
         title="Logic used by the plan definition",
@@ -340,13 +349,51 @@ class PlanDefinition(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    subjectCanonical: fhirtypes.Canonical = Field(
+        None,
+        alias="subjectCanonical",
+        title="Type of individual the plan definition is focused on",
+        description=(
+            "A code, group definition, or canonical reference that describes  or "
+            "identifies the intended subject of the plan definition. Canonical "
+            "references are allowed to support the definition of protocols for drug"
+            " and substance quality specifications, and is allowed to reference a "
+            "MedicinalProductDefinition, SubstanceDefinition, "
+            "AdministrableProductDefinition, ManufacturedItemDefinition, or "
+            "PackagedProductDefinition resource."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e subject[x]
+        one_of_many="subject",
+        one_of_many_required=False,
+        # note: Listed Resource Type(s) should be allowed as Reference.
+        enum_reference_types=[
+            "MedicinalProductDefinition",
+            "SubstanceDefinition",
+            "AdministrableProductDefinition",
+            "ManufacturedItemDefinition",
+            "PackagedProductDefinition",
+        ],
+    )
+    subjectCanonical__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_subjectCanonical",
+        title="Extension field for ``subjectCanonical``.",
+    )
+
     subjectCodeableConcept: fhirtypes.CodeableConceptType = Field(
         None,
         alias="subjectCodeableConcept",
         title="Type of individual the plan definition is focused on",
         description=(
-            "A code or group definition that describes the intended subject of the "
-            "plan definition."
+            "A code, group definition, or canonical reference that describes  or "
+            "identifies the intended subject of the plan definition. Canonical "
+            "references are allowed to support the definition of protocols for drug"
+            " and substance quality specifications, and is allowed to reference a "
+            "MedicinalProductDefinition, SubstanceDefinition, "
+            "AdministrableProductDefinition, ManufacturedItemDefinition, or "
+            "PackagedProductDefinition resource."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -360,8 +407,13 @@ class PlanDefinition(domainresource.DomainResource):
         alias="subjectReference",
         title="Type of individual the plan definition is focused on",
         description=(
-            "A code or group definition that describes the intended subject of the "
-            "plan definition."
+            "A code, group definition, or canonical reference that describes  or "
+            "identifies the intended subject of the plan definition. Canonical "
+            "references are allowed to support the definition of protocols for drug"
+            " and substance quality specifications, and is allowed to reference a "
+            "MedicinalProductDefinition, SubstanceDefinition, "
+            "AdministrableProductDefinition, ManufacturedItemDefinition, or "
+            "PackagedProductDefinition resource."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -502,6 +554,56 @@ class PlanDefinition(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "identifier",
+            "version",
+            "name",
+            "title",
+            "subtitle",
+            "type",
+            "status",
+            "experimental",
+            "subjectCodeableConcept",
+            "subjectReference",
+            "subjectCanonical",
+            "date",
+            "publisher",
+            "contact",
+            "description",
+            "useContext",
+            "jurisdiction",
+            "purpose",
+            "usage",
+            "copyright",
+            "approvalDate",
+            "lastReviewDate",
+            "effectivePeriod",
+            "topic",
+            "author",
+            "editor",
+            "reviewer",
+            "endorser",
+            "relatedArtifact",
+            "library",
+            "goal",
+            "action",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1618(
         cls, values: typing.Dict[str, typing.Any]
@@ -577,7 +679,13 @@ class PlanDefinition(domainresource.DomainResource):
         choice of types, the authoring system must create a single element with a
         data type chosen from among the list of permitted data types.
         """
-        one_of_many_fields = {"subject": ["subjectCodeableConcept", "subjectReference"]}
+        one_of_many_fields = {
+            "subject": [
+                "subjectCanonical",
+                "subjectCodeableConcept",
+                "subjectReference",
+            ]
+        }
         for prefix, fields in one_of_many_fields.items():
             assert cls.__fields__[fields[0]].field_info.extra["one_of_many"] == prefix
             required = (
@@ -601,12 +709,16 @@ class PlanDefinition(domainresource.DomainResource):
 
 
 class PlanDefinitionAction(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
     Action defined by the plan.
-    An action or group of actions to be taken as part of the plan.
+    An action or group of actions to be taken as part of the plan. For example,
+    in clinical care, an action would be to prescribe a particular indicated
+    medication, or perform a particular test as appropriate. In pharmaceutical
+    quality, an action would be the test that needs to be performed on a drug
+    product as defined in the quality specification.
     """
 
     resource_type = Field("PlanDefinitionAction", const=True)
@@ -647,9 +759,11 @@ class PlanDefinitionAction(backboneelement.BackboneElement):
         alias="code",
         title="Code representing the meaning of the action or sub-actions",
         description=(
-            "A code that provides meaning for the action or action group. For "
-            "example, a section may have a LOINC code for the section of a "
-            "documentation template."
+            "A code that provides a meaning, grouping, or classification for the "
+            "action or action group. For example, a section may have a LOINC code "
+            "for the section of a documentation template. In pharmaceutical "
+            "quality, an action (Test) such as pH could be classified as a physical"
+            " property."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -752,13 +866,16 @@ class PlanDefinitionAction(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    goalId: typing.List[fhirtypes.Id] = Field(
+    goalId: typing.List[typing.Optional[fhirtypes.Id]] = Field(
         None,
         alias="goalId",
         title="What goals this action supports",
         description=(
             "Identifies goals that this action supports. The reference must be to a"
-            " goal element defined within this plan definition."
+            " goal element defined within this plan definition. In pharmaceutical "
+            "quality, a goal represents acceptance criteria (Goal) for a given "
+            "action (Test), so the goalId would be the unique id of a defined goal "
+            "element establishing the acceptance criteria for the action."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -920,13 +1037,43 @@ class PlanDefinitionAction(backboneelement.BackboneElement):
         title="Extension field for ``selectionBehavior``.",
     )
 
+    subjectCanonical: fhirtypes.Canonical = Field(
+        None,
+        alias="subjectCanonical",
+        title="Type of individual the action is focused on",
+        description=(
+            "A code, group definition, or canonical reference that describes the "
+            "intended subject of the action and its children, if any. Canonical "
+            "references are allowed to support the definition of protocols for drug"
+            " and substance quality specifications, and is allowed to reference a "
+            "MedicinalProductDefinition, SubstanceDefinition, "
+            "AdministrableProductDefinition, ManufacturedItemDefinition, or "
+            "PackagedProductDefinition resource."
+        ),
+        # if property is element of this resource.
+        element_property=True,
+        # Choice of Data Types. i.e subject[x]
+        one_of_many="subject",
+        one_of_many_required=False,
+    )
+    subjectCanonical__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
+        None,
+        alias="_subjectCanonical",
+        title="Extension field for ``subjectCanonical``.",
+    )
+
     subjectCodeableConcept: fhirtypes.CodeableConceptType = Field(
         None,
         alias="subjectCodeableConcept",
         title="Type of individual the action is focused on",
         description=(
-            "A code or group definition that describes the intended subject of the "
-            "action and its children, if any."
+            "A code, group definition, or canonical reference that describes the "
+            "intended subject of the action and its children, if any. Canonical "
+            "references are allowed to support the definition of protocols for drug"
+            " and substance quality specifications, and is allowed to reference a "
+            "MedicinalProductDefinition, SubstanceDefinition, "
+            "AdministrableProductDefinition, ManufacturedItemDefinition, or "
+            "PackagedProductDefinition resource."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -940,8 +1087,13 @@ class PlanDefinitionAction(backboneelement.BackboneElement):
         alias="subjectReference",
         title="Type of individual the action is focused on",
         description=(
-            "A code or group definition that describes the intended subject of the "
-            "action and its children, if any."
+            "A code, group definition, or canonical reference that describes the "
+            "intended subject of the action and its children, if any. Canonical "
+            "references are allowed to support the definition of protocols for drug"
+            " and substance quality specifications, and is allowed to reference a "
+            "MedicinalProductDefinition, SubstanceDefinition, "
+            "AdministrableProductDefinition, ManufacturedItemDefinition, or "
+            "PackagedProductDefinition resource."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1051,7 +1203,11 @@ class PlanDefinitionAction(backboneelement.BackboneElement):
         None,
         alias="title",
         title="User-visible title",
-        description="The title of the action displayed to a user.",
+        description=(
+            "The textual description of the action displayed to a user. For "
+            "example, when the action is a test to be performed, the title would be"
+            " the title of the test such as Assay by HPLC."
+        ),
         # if property is element of this resource.
         element_property=True,
     )
@@ -1095,6 +1251,53 @@ class PlanDefinitionAction(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionAction`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "prefix",
+            "title",
+            "description",
+            "textEquivalent",
+            "priority",
+            "code",
+            "reason",
+            "documentation",
+            "goalId",
+            "subjectCodeableConcept",
+            "subjectReference",
+            "subjectCanonical",
+            "trigger",
+            "condition",
+            "input",
+            "output",
+            "relatedAction",
+            "timingDateTime",
+            "timingAge",
+            "timingPeriod",
+            "timingDuration",
+            "timingRange",
+            "timingTiming",
+            "participant",
+            "type",
+            "groupingBehavior",
+            "selectionBehavior",
+            "requiredBehavior",
+            "precheckBehavior",
+            "cardinalityBehavior",
+            "definitionCanonical",
+            "definitionUri",
+            "transform",
+            "dynamicValue",
+            "action",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_2224(
         cls, values: typing.Dict[str, typing.Any]
@@ -1113,7 +1316,11 @@ class PlanDefinitionAction(backboneelement.BackboneElement):
         """
         one_of_many_fields = {
             "definition": ["definitionCanonical", "definitionUri"],
-            "subject": ["subjectCodeableConcept", "subjectReference"],
+            "subject": [
+                "subjectCanonical",
+                "subjectCodeableConcept",
+                "subjectReference",
+            ],
             "timing": [
                 "timingAge",
                 "timingDateTime",
@@ -1146,7 +1353,7 @@ class PlanDefinitionAction(backboneelement.BackboneElement):
 
 
 class PlanDefinitionActionCondition(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1185,6 +1392,14 @@ class PlanDefinitionActionCondition(backboneelement.BackboneElement):
         None, alias="_kind", title="Extension field for ``kind``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionActionCondition`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "kind", "expression"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3159(
         cls, values: typing.Dict[str, typing.Any]
@@ -1246,7 +1461,7 @@ class PlanDefinitionActionCondition(backboneelement.BackboneElement):
 
 
 class PlanDefinitionActionDynamicValue(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1291,9 +1506,17 @@ class PlanDefinitionActionDynamicValue(backboneelement.BackboneElement):
         None, alias="_path", title="Extension field for ``path``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionActionDynamicValue`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "path", "expression"]
+
 
 class PlanDefinitionActionParticipant(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1331,6 +1554,14 @@ class PlanDefinitionActionParticipant(backboneelement.BackboneElement):
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionActionParticipant`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "type", "role"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3381(
         cls, values: typing.Dict[str, typing.Any]
@@ -1392,7 +1623,7 @@ class PlanDefinitionActionParticipant(backboneelement.BackboneElement):
 
 
 class PlanDefinitionActionRelatedAction(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1475,6 +1706,22 @@ class PlanDefinitionActionRelatedAction(backboneelement.BackboneElement):
         None, alias="_relationship", title="Extension field for ``relationship``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionActionRelatedAction`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "actionId",
+            "relationship",
+            "offsetDuration",
+            "offsetRange",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3535(
         cls, values: typing.Dict[str, typing.Any]
@@ -1577,15 +1824,16 @@ class PlanDefinitionActionRelatedAction(backboneelement.BackboneElement):
 
 
 class PlanDefinitionGoal(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
     What the plan is trying to accomplish.
-    Goals that describe what the activities within the plan are intended to
-    achieve. For example, weight loss, restoring an activity of daily living,
-    obtaining herd immunity via immunization, meeting a process improvement
-    objective, etc.
+    A goal describes an expected outcome that activities within the plan are
+    intended to achieve. For example, weight loss, restoring an activity of
+    daily living, obtaining herd immunity via immunization, meeting a process
+    improvement objective, meeting the acceptance criteria for a test as
+    specified by a quality specification, etc.
     """
 
     resource_type = Field("PlanDefinitionGoal", const=True)
@@ -1668,9 +1916,28 @@ class PlanDefinitionGoal(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionGoal`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "category",
+            "description",
+            "priority",
+            "start",
+            "addresses",
+            "documentation",
+            "target",
+        ]
+
 
 class PlanDefinitionGoalTarget(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1686,11 +1953,13 @@ class PlanDefinitionGoalTarget(backboneelement.BackboneElement):
         title="The target value to be achieved",
         description=(
             "The target value of the measure to be achieved to signify fulfillment "
-            "of the goal, e.g. 150 pounds or 7.0%. Either the high or low or both "
-            "values of the range can be specified. When a low value is missing, it "
-            "indicates that the goal is achieved at any value at or below the high "
-            "value. Similarly, if the high value is missing, it indicates that the "
-            "goal is achieved at any value at or above the low value."
+            "of the goal, e.g. 150 pounds or 7.0%, or in the case of pharmaceutical"
+            " quality - NMT 0.6%, Clear solution, etc. Either the high or low or "
+            "both values of the range can be specified. When a low value is "
+            "missing, it indicates that the goal is achieved at any value at or "
+            "below the high value. Similarly, if the high value is missing, it "
+            "indicates that the goal is achieved at any value at or above the low "
+            "value."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1705,11 +1974,13 @@ class PlanDefinitionGoalTarget(backboneelement.BackboneElement):
         title="The target value to be achieved",
         description=(
             "The target value of the measure to be achieved to signify fulfillment "
-            "of the goal, e.g. 150 pounds or 7.0%. Either the high or low or both "
-            "values of the range can be specified. When a low value is missing, it "
-            "indicates that the goal is achieved at any value at or below the high "
-            "value. Similarly, if the high value is missing, it indicates that the "
-            "goal is achieved at any value at or above the low value."
+            "of the goal, e.g. 150 pounds or 7.0%, or in the case of pharmaceutical"
+            " quality - NMT 0.6%, Clear solution, etc. Either the high or low or "
+            "both values of the range can be specified. When a low value is "
+            "missing, it indicates that the goal is achieved at any value at or "
+            "below the high value. Similarly, if the high value is missing, it "
+            "indicates that the goal is achieved at any value at or above the low "
+            "value."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1724,11 +1995,13 @@ class PlanDefinitionGoalTarget(backboneelement.BackboneElement):
         title="The target value to be achieved",
         description=(
             "The target value of the measure to be achieved to signify fulfillment "
-            "of the goal, e.g. 150 pounds or 7.0%. Either the high or low or both "
-            "values of the range can be specified. When a low value is missing, it "
-            "indicates that the goal is achieved at any value at or below the high "
-            "value. Similarly, if the high value is missing, it indicates that the "
-            "goal is achieved at any value at or above the low value."
+            "of the goal, e.g. 150 pounds or 7.0%, or in the case of pharmaceutical"
+            " quality - NMT 0.6%, Clear solution, etc. Either the high or low or "
+            "both values of the range can be specified. When a low value is "
+            "missing, it indicates that the goal is achieved at any value at or "
+            "below the high value. Similarly, if the high value is missing, it "
+            "indicates that the goal is achieved at any value at or above the low "
+            "value."
         ),
         # if property is element of this resource.
         element_property=True,
@@ -1761,6 +2034,23 @@ class PlanDefinitionGoalTarget(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PlanDefinitionGoalTarget`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "measure",
+            "detailQuantity",
+            "detailRange",
+            "detailCodeableConcept",
+            "due",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_2626(
         cls, values: typing.Dict[str, typing.Any]
