@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/PractitionerRole
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class PractitionerRole(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -200,9 +200,40 @@ class PractitionerRole(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PractitionerRole`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "active",
+            "period",
+            "practitioner",
+            "organization",
+            "code",
+            "specialty",
+            "location",
+            "healthcareService",
+            "telecom",
+            "availableTime",
+            "notAvailable",
+            "availabilityExceptions",
+            "endpoint",
+        ]
+
 
 class PractitionerRoleAvailableTime(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -262,7 +293,7 @@ class PractitionerRoleAvailableTime(backboneelement.BackboneElement):
         title="Extension field for ``availableStartTime``.",
     )
 
-    daysOfWeek: typing.List[fhirtypes.Code] = Field(
+    daysOfWeek: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="daysOfWeek",
         title="mon | tue | wed | thu | fri | sat | sun",
@@ -280,9 +311,25 @@ class PractitionerRoleAvailableTime(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_daysOfWeek", title="Extension field for ``daysOfWeek``.")
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PractitionerRoleAvailableTime`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "daysOfWeek",
+            "allDay",
+            "availableStartTime",
+            "availableEndTime",
+        ]
+
 
 class PractitionerRoleNotAvailable(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -321,6 +368,14 @@ class PractitionerRoleNotAvailable(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PractitionerRoleNotAvailable`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "description", "during"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3053(
         cls, values: typing.Dict[str, typing.Any]
