@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/ResearchDefinition
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -57,7 +57,7 @@ class ResearchDefinition(domainresource.DomainResource):
         element_property=True,
     )
 
-    comment: typing.List[fhirtypes.String] = Field(
+    comment: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="comment",
         title="Used for footnotes or explanatory notes",
@@ -254,7 +254,7 @@ class ResearchDefinition(domainresource.DomainResource):
         None, alias="_lastReviewDate", title="Extension field for ``lastReviewDate``."
     )
 
-    library: typing.List[fhirtypes.Canonical] = Field(
+    library: typing.List[typing.Optional[fhirtypes.Canonical]] = Field(
         None,
         alias="library",
         title="Logic used by the ResearchDefinition",
