@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/SearchParameter
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class SearchParameter(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -27,7 +27,7 @@ class SearchParameter(domainresource.DomainResource):
 
     resource_type = Field("SearchParameter", const=True)
 
-    base: typing.List[fhirtypes.Code] = Field(
+    base: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="base",
         title="The resource type(s) this search parameter applies to",
@@ -43,7 +43,7 @@ class SearchParameter(domainresource.DomainResource):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_base", title="Extension field for ``base``.")
 
-    chain: typing.List[fhirtypes.String] = Field(
+    chain: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="chain",
         title="Chained names supported",
@@ -79,7 +79,7 @@ class SearchParameter(domainresource.DomainResource):
         None, alias="_code", title="Extension field for ``code``."
     )
 
-    comparator: typing.List[fhirtypes.Code] = Field(
+    comparator: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="comparator",
         title="eq | ne | gt | lt | ge | le | sa | eb | ap",
@@ -208,7 +208,7 @@ class SearchParameter(domainresource.DomainResource):
         element_property=True,
     )
 
-    modifier: typing.List[fhirtypes.Code] = Field(
+    modifier: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="modifier",
         title=(
@@ -336,7 +336,7 @@ class SearchParameter(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
-    target: typing.List[fhirtypes.Code] = Field(
+    target: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="target",
         title="Types of resource (if a resource reference)",
@@ -472,6 +472,49 @@ class SearchParameter(domainresource.DomainResource):
         None, alias="_xpathUsage", title="Extension field for ``xpathUsage``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SearchParameter`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "version",
+            "name",
+            "derivedFrom",
+            "status",
+            "experimental",
+            "date",
+            "publisher",
+            "contact",
+            "description",
+            "useContext",
+            "jurisdiction",
+            "purpose",
+            "code",
+            "base",
+            "type",
+            "expression",
+            "xpath",
+            "xpathUsage",
+            "target",
+            "multipleOr",
+            "multipleAnd",
+            "comparator",
+            "modifier",
+            "chain",
+            "component",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1724(
         cls, values: typing.Dict[str, typing.Any]
@@ -541,7 +584,7 @@ class SearchParameter(domainresource.DomainResource):
 
 
 class SearchParameterComponent(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -582,6 +625,14 @@ class SearchParameterComponent(backboneelement.BackboneElement):
         None, alias="_expression", title="Extension field for ``expression``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SearchParameterComponent`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "definition", "expression"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2673(
         cls, values: typing.Dict[str, typing.Any]
