@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Specimen
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -14,7 +14,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Specimen(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -177,9 +177,39 @@ class Specimen(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Specimen`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "accessionIdentifier",
+            "status",
+            "type",
+            "subject",
+            "receivedTime",
+            "parent",
+            "request",
+            "collection",
+            "processing",
+            "container",
+            "condition",
+            "note",
+        ]
+
 
 class SpecimenCollection(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -311,6 +341,27 @@ class SpecimenCollection(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SpecimenCollection`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "collector",
+            "collectedDateTime",
+            "collectedPeriod",
+            "duration",
+            "quantity",
+            "method",
+            "bodySite",
+            "fastingStatusCodeableConcept",
+            "fastingStatusDuration",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_2049(
         cls, values: typing.Dict[str, typing.Any]
@@ -354,7 +405,7 @@ class SpecimenCollection(backboneelement.BackboneElement):
 
 
 class SpecimenContainer(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -455,6 +506,25 @@ class SpecimenContainer(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SpecimenContainer`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "description",
+            "type",
+            "capacity",
+            "specimenQuantity",
+            "additiveCodeableConcept",
+            "additiveReference",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_1948(
         cls, values: typing.Dict[str, typing.Any]
@@ -497,7 +567,7 @@ class SpecimenContainer(backboneelement.BackboneElement):
 
 
 class SpecimenProcessing(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -574,6 +644,23 @@ class SpecimenProcessing(backboneelement.BackboneElement):
         one_of_many_required=False,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SpecimenProcessing`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "description",
+            "procedure",
+            "additive",
+            "timeDateTime",
+            "timePeriod",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_2059(
         cls, values: typing.Dict[str, typing.Any]
