@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/StructureDefinition
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -87,7 +87,7 @@ class StructureDefinition(domainresource.DomainResource):
         element_property=True,
     )
 
-    contextInvariant: typing.List[fhirtypes.String] = Field(
+    contextInvariant: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="contextInvariant",
         title="FHIRPath invariants - when the extension can be used",
@@ -207,7 +207,7 @@ class StructureDefinition(domainresource.DomainResource):
             "The version of the FHIR specification on which this "
             "StructureDefinition is based - this is the formal version of the "
             "specification, without the revision number, e.g. "
-            "[publication].[major].[minor], which is 4.0.1. for this version."
+            "[publication].[major].[minor], which is 4.3.0 for this version."
         ),
         # if property is element of this resource.
         element_property=True,
