@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/TerminologyCapabilities
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -661,7 +661,7 @@ class TerminologyCapabilitiesCodeSystemVersion(backboneelement.BackboneElement):
         None, alias="_isDefault", title="Extension field for ``isDefault``."
     )
 
-    language: typing.List[fhirtypes.Code] = Field(
+    language: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="language",
         title="Language Displays supported",
@@ -673,7 +673,7 @@ class TerminologyCapabilitiesCodeSystemVersion(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_language", title="Extension field for ``language``.")
 
-    property: typing.List[fhirtypes.Code] = Field(
+    property: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="property",
         title="Properties supported for $lookup",
@@ -727,7 +727,7 @@ class TerminologyCapabilitiesCodeSystemVersionFilter(backboneelement.BackboneEle
         None, alias="_code", title="Extension field for ``code``."
     )
 
-    op: typing.List[fhirtypes.Code] = Field(
+    op: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="op",
         title="Operations supported for the property",
