@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/TestScript
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -834,7 +834,7 @@ class TestScriptMetadataCapability(backboneelement.BackboneElement):
         None, alias="_destination", title="Extension field for ``destination``."
     )
 
-    link: typing.List[fhirtypes.Uri] = Field(
+    link: typing.List[typing.Optional[fhirtypes.Uri]] = Field(
         None,
         alias="link",
         title="Links to the FHIR specification",
@@ -849,7 +849,7 @@ class TestScriptMetadataCapability(backboneelement.BackboneElement):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_link", title="Extension field for ``link``.")
 
-    origin: typing.List[fhirtypes.Integer] = Field(
+    origin: typing.List[typing.Optional[fhirtypes.Integer]] = Field(
         None,
         alias="origin",
         title="Which origin server these requirements apply to",
