@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/Timing
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -14,7 +14,7 @@ from . import backboneelement, element, fhirtypes
 
 
 class Timing(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -45,7 +45,7 @@ class Timing(backboneelement.BackboneElement):
         element_property=True,
     )
 
-    event: typing.List[fhirtypes.DateTime] = Field(
+    event: typing.List[typing.Optional[fhirtypes.DateTime]] = Field(
         None,
         alias="event",
         title="When the event occurs",
@@ -66,9 +66,17 @@ class Timing(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Timing`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "event", "repeat", "code"]
+
 
 class TimingRepeat(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -158,7 +166,7 @@ class TimingRepeat(element.Element):
         None, alias="_countMax", title="Extension field for ``countMax``."
     )
 
-    dayOfWeek: typing.List[fhirtypes.Code] = Field(
+    dayOfWeek: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="dayOfWeek",
         title="mon | tue | wed | thu | fri | sat | sun",
@@ -318,7 +326,7 @@ class TimingRepeat(element.Element):
         None, alias="_periodUnit", title="Extension field for ``periodUnit``."
     )
 
-    timeOfDay: typing.List[fhirtypes.Time] = Field(
+    timeOfDay: typing.List[typing.Optional[fhirtypes.Time]] = Field(
         None,
         alias="timeOfDay",
         title="Time of day for action",
@@ -330,7 +338,7 @@ class TimingRepeat(element.Element):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_timeOfDay", title="Extension field for ``timeOfDay``.")
 
-    when: typing.List[fhirtypes.Code] = Field(
+    when: typing.List[typing.Optional[fhirtypes.Code]] = Field(
         None,
         alias="when",
         title="Code for time period of occurrence",
@@ -345,6 +353,34 @@ class TimingRepeat(element.Element):
         typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]
     ] = Field(None, alias="_when", title="Extension field for ``when``.")
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TimingRepeat`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "boundsDuration",
+            "boundsRange",
+            "boundsPeriod",
+            "count",
+            "countMax",
+            "duration",
+            "durationMax",
+            "durationUnit",
+            "frequency",
+            "frequencyMax",
+            "period",
+            "periodMax",
+            "periodUnit",
+            "dayOfWeek",
+            "timeOfDay",
+            "when",
+            "offset",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_1425(
         cls, values: typing.Dict[str, typing.Any]
