@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 Profile: http://hl7.org/fhir/StructureDefinition/VerificationResult
-Release: R4
-Version: 4.0.1
-Build ID: 9346c8cc45
-Last updated: 2019-11-01T09:29:23.356+11:00
+Release: R4B
+Version: 4.3.0
+Build ID: c475c22
+Last updated: 2022-05-28T12:47:40.239+10:00
 """
 import typing
 
@@ -152,7 +152,7 @@ class VerificationResult(domainresource.DomainResource):
         enum_reference_types=["Resource"],
     )
 
-    targetLocation: typing.List[fhirtypes.String] = Field(
+    targetLocation: typing.List[typing.Optional[fhirtypes.String]] = Field(
         None,
         alias="targetLocation",
         title="The fhirpath location(s) within the resource that was validated",
